Ipv4

Struct Ipv4 

pub struct Ipv4<'a> { /* private fields */ }
An IPv4 packet.

IPv4 options are not parsed by default.

Implementations

Source

impl Ipv4<'_>

pub fn version(&self) -> u8

Returns the IP protocol version.

pub fn ihl(&self) -> u8

Returns the header length measured in 32-bit words (IHL).

pub fn version_ihl(&self) -> u8

Returns the 8-bit field containing the version and IHL.

pub fn dscp(&self) -> u8

Returns the differentiated services code point (DSCP).

pub fn ecn(&self) -> u8

Returns the explicit congestion notification (ECN).

pub fn dscp_ecn(&self) -> u8

Returns the differentiated services field.

pub fn type_of_service(&self) -> u8

Returns the type of service (former name of the differentiated services field).

pub fn total_length(&self) -> u16

Returns the total length of the packet in bytes, including the header and data.

pub fn identification(&self) -> u16

Returns the identification field.

pub fn flags_to_fragment_offset(&self) -> u16

Returns the 16-bit field containing the 3-bit flags and 13-bit fragment offset.

pub fn flags(&self) -> u8

Returns the 3-bit IP flags.

pub fn rf(&self) -> bool

Returns true if the Reserved flag is set.

pub fn df(&self) -> bool

Returns true if the Don’t Fragment flag is set.

pub fn mf(&self) -> bool

Returns true if the More Fragments flag is set.

pub fn fragment_offset(&self) -> u16

Returns the fragment offset in units of 8 bytes.

pub fn time_to_live(&self) -> u8

Returns the time to live (TTL) of the packet.

pub fn protocol(&self) -> u8

Returns the encapsulated protocol identifier.

pub fn header_checksum(&self) -> u16

Returns the IPv4 header checksum.

pub fn src_addr(&self) -> Ipv4Addr

Returns the sender’s IPv4 address.

pub fn dst_addr(&self) -> Ipv4Addr

Returns the receiver’s IPv4 address.